@@ -1,10 +1,13 @@
 __all__ = ["SavedQuery"]
 
+from cannerflow.request import CannerRequest
+
+
 class SavedQuery(object):
     def __init__(
         self,
-        workspace_id,
-        request
+        request: CannerRequest,
+        workspace_id: str
     ):
         self.workspace_id = workspace_id
         self.request = request
@@ -29,7 +32,7 @@ class SavedQuery(object):
             }
         }
     def fetch(self):
-        return self.request.post(self.getPayload()).get('sqls')
+        return self.request.graphql_exec(self.getPayload()).get('sqls')
     def list_title(self):
         data = self.fetch()
         return list(map(lambda x: x['title'], data))
